pub struct ValidationReport {
pub document: Option<Document>,
pub findings: Vec<Finding>,
pub errors: Vec<Finding>,
pub warnings: Vec<Finding>,
pub ok: bool,
}Expand description
The complete result of parsing and validating an AGS document.
Fields
document: Option<Document>Parsed document, absent only when loading or parsing failed.
findings: Vec<Finding>All errors and warnings in discovery order.
errors: Vec<Finding>Findings whose severity is error.
warnings: Vec<Finding>Findings whose severity is warning.
ok: boolWhether the document has no validation errors.